function newtonKonvergenzDF
  % Parameter von Newton Verfahren
  ATOL = 1e-8;
  RTOL = 1e-5;
  nMax = 1000;

  % Polynom und seine Ableitung
  F  = @(x) (x-1).*(x-2);
  h  = 1e-7;
  x0 = pi/4;

  % Anfangswert und Wert von F im Anfangswert
  x = x0;
  Fx_new = F(x);

  % Speichere Anfangswert
  xsave(1) = x;

  % Newton iterationen
  for ii = 1:nMax
    % Wert von F und DF in alter Iterierte
    Fx = Fx_new;
    DFx = (F(x+h)-Fx_new)/h;

    % Newton update
    delta_x = - DFx\Fx;

    % Neue Iterierte
    x = x + delta_x;

    % Speichere neuen Wert
    xsave(ii+1) = x;

    % Wert von F an neuer Iterierte
    Fx_new = F(x);

    % Wenn update zu klein -> stop and exit
    if abs(DFx\Fx_new) < ATOL + RTOL*norm(x)
      break
    end
  end

  % Absoluter Fehler
  format long;
  err = abs(xsave-1)

  % Konvergenzrate
  format short;
  p = log(err(3:end)./err(2:end-1))./log(err(2:end-1)./err(1:end-2))
end
